import { getTokenAtPosition, getTypeInfo, getAutocompleteSuggestions, getDiagnostics } from 'graphql-language-service';
import { StateEffect, StateField } from '@codemirror/state';
import { LRParser } from '@lezer/lr';
import { LRLanguage, indentNodeProp, delimitedIndent, foldNodeProp, foldInside, LanguageSupport } from '@codemirror/language';
import { styleTags, tags } from '@lezer/highlight';
import { EditorView } from '@codemirror/view';
import { linter } from '@codemirror/lint';

function posToOffset(doc, pos) {
    return doc.line(pos.line + 1).from + pos.character;
}
function offsetToPos(doc, offset) {
    const line = doc.lineAt(offset);
    return new Position(line.number - 1, offset - line.from);
}
class Position {
    constructor(line, character) {
        this.line = line;
        this.character = character;
    }
    setLine(line) {
        this.line = line;
    }
    setCharacter(character) {
        this.character = character;
    }
    lessThanOrEqualTo(position) {
        return (this.line < position.line ||
            (this.line === position.line && this.character <= position.character));
    }
}
const isMac = () => /mac/i.test(navigator.platform);
const isMetaKeyPressed = (e) => isMac() ? e.metaKey : e.ctrlKey;

const schemaEffect = /*@__PURE__*/StateEffect.define();
const schemaStateField = /*@__PURE__*/StateField.define({
    create() { },
    update(schema, tr) {
        for (const e of tr.effects) {
            if (e.is(schemaEffect)) {
                return e.value;
            }
        }
        return schema;
    },
});
const optionsEffect = /*@__PURE__*/StateEffect.define();
const optionsStateField = /*@__PURE__*/StateField.define({
    create() { },
    update(opts, tr) {
        for (const e of tr.effects) {
            if (e.is(optionsEffect)) {
                return e.value;
            }
        }
        return opts;
    },
});
const updateSchema = (view, schema) => {
    view.dispatch({
        effects: schemaEffect.of(schema),
    });
};
const updateOpts = (view, opts) => {
    view.dispatch({
        effects: optionsEffect.of(opts),
    });
};
const getSchema = (state) => {
    return state.field(schemaStateField);
};
const getOpts = (state) => {
    return state.field(optionsStateField);
};
const stateExtensions = (schema, opts) => [schemaStateField.init(() => schema), optionsStateField.init(() => opts)];

const fillAllFieldsCommands = (view) => {
    const schema = getSchema(view.state);
    if (!schema) {
        return true;
    }
    const opts = getOpts(view.state);
    const currentPosition = view.state.selection.main.head;
    const pos = offsetToPos(view.state.doc, currentPosition);
    const token = getTokenAtPosition(view.state.doc.toString(), pos);
    if (schema && (opts === null || opts === void 0 ? void 0 : opts.onFillAllFields)) {
        opts.onFillAllFields(view, schema, view.state.doc.toString(), pos, token);
    }
    return true;
};
const showInDocsCommand = (view) => {
    var _a, _b, _c;
    const schema = getSchema(view.state);
    if (!schema) {
        return true;
    }
    const opts = getOpts(view.state);
    const currentPosition = view.state.selection.main.head;
    const pos = offsetToPos(view.state.doc, currentPosition);
    const token = getTokenAtPosition(view.state.doc.toString(), pos);
    if (schema && (opts === null || opts === void 0 ? void 0 : opts.onShowInDocs)) {
        const tInfo = getTypeInfo(schema, token.state);
        opts.onShowInDocs((_a = tInfo.fieldDef) === null || _a === void 0 ? void 0 : _a.name, (_b = tInfo.type) === null || _b === void 0 ? void 0 : _b.toString(), (_c = tInfo.parentType) === null || _c === void 0 ? void 0 : _c.toString());
    }
    return true;
};

// This file was generated by lezer-generator. You probably shouldn't edit it.
const spec_name = {__proto__:null,query:241, mutation:243, subscription:245, on:86, fragment:92, schema:102, scalar:114, type:120, implements:126, interface:140, union:146, enum:154, input:164, directive:172, repeatable:176, extend:192};
const parser = /*@__PURE__*/LRParser.deserialize({
  version: 14,
  states: "LQOYQPOOO!WQPO'#C}O!`QPO'#C_OOQO'#C_'#C_O!iQPO'#DYOOQO'#Ev'#EvOOQO'#D_'#D_O!nQPO'#D^O#_QPO'#D^O!iQPO'#DhO!iQPO'#DrO!iQPO'#DuO!iQPO'#DyO!iQPO'#EOOOQO'#Dd'#DdO#fQPO'#ESOOQO'#D]'#D]O!vQPO'#E^OOQO'#Ea'#EaOOQO'#E]'#E]OOQO'#FT'#FTOOQO'#Eu'#EuOOQO'#Eh'#EhQYQPOOOOQO'#C`'#C`OOQO'#DZ'#DZOOQO'#D`'#D`OOQO'#Di'#DiOOQO'#Ds'#DsOOQO'#Dv'#DvOOQO'#Dz'#DzOOQO'#EP'#EPOOQO'#ET'#ETOOQO'#E_'#E_O#kQPO'#CaO$VQPO'#DQO$[QPO'#DPO$sQPO'#DPO$xQPO'#DSO%WQPO'#DOOOQO'#En'#EnO%fQPO,59iOOQO'#Ca'#CaO%qQPO'#CxOOQO'#El'#ElO'hQPO'#CwO)[QPO'#CdOOQO,58y,58yO)aQPO,58yO)fQPO,58yO)nQPO,58yOOQO'#DT'#DTO)yQPO,59tO{QPO'#FUOOQO'#Db'#DbOOQO,59x,59xO*OQPO,59xO!nQPO,59xO!iQPO,5:PO!iQPO,5:SO!iQPO,5:^O!iQPO,5:aO!iQPO,5:eO!iQPO,5:jO*TQPO,5:nOOQO'#Df'#DfO*YQPO,5:SO+aQPO,5:^O,hQPO,5:aO-oQPO,5:eO.sQPO,5:jO/wQPO,5:nO!nQPO,5:xO!iQPO,5:|O!iQPO,5:}O!iQPO,5;OO!iQPO,5;PO!iQPO,5;QO!iQPO,5;ROOQO-E8f-E8fOOQO,59l,59lO0VQPO'#CzOOQO,59k,59kO0[QPO,59kO0mQPO,59kOOQO'#DR'#DRO0tQPO,59kO1OQPO,59nO!iQPO'#DVOOQO,59p,59pO)aQPO,59pO)fQPO,59pOOQO'#DW'#DWOOQO,59j,59jOOQO-E8l-E8lOOQO1G/T1G/TOOQO,59d,59dOOQO-E8j-E8jO1aQPO'#CeOOQO'#Ei'#EiO1fQPO,59OOOQO1G.e1G.eO)aQPO1G.eO)fQPO1G.eO)fQPO1G/`O1nQPO'#DcO1sQPO,5;pOOQO1G/d1G/dO*OQPO1G/dO1xQPO1G/kO4QQPO1G/nO5]QPO1G/xO6hQPO1G/{O7pQPO1G0PO8xQPO1G0UO/wQPO1G0YO9PQPO1G/nO9WQPO'#DkO9`QPO'#FWOOQO'#Dn'#DnOOQO1G/n1G/nO9hQPO1G/nOOQO'#Dl'#DlO:iQPO1G/xOOQO1G/x1G/xO:pQPO1G/xO;qQPO1G/{O;xQPO'#DxO5dQPO1G/{O<QQQO'#FYOOQO'#D|'#D|OOQO1G0P1G0PO6oQPO1G0PO9`QPO'#FZOOQO'#ER'#EROOQO1G0U1G0UO7wQPO1G0UO<YQPO'#DqO!iQPO'#DqOOQO'#Ep'#EpO<_QPO'#DpO<pQSO1G0YO)yQPO1G0YO>QQPO1G0YOOQO'#EV'#EVOOQO1G0d1G0dO>YQPO1G0dO!qQPO1G0hO?ZQPO1G0iO?ZQPO1G0jO?fQPO1G0kO?nQPO1G0lO?vQPO1G0mOOQO'#C|'#C|O@OQPO'#C{OOQO'#Em'#EmO@TQPO,59fOOQO1G/V1G/VO@]QPO1G/VO@nQPO1G/VOOQO1G/Y1G/YOOQO'#Cg'#CgOOQO,59q,59qOOQO1G/[1G/[O)aQPO1G/[O@uQPO,59POOQO-E8g-E8gOOQO1G.j1G.jOOQO7+$P7+$PO)aQPO7+$POOQO7+$z7+$zO)aQPO7+$zO!iQPO,59}OOQO1G1[1G1[OOQO7+%O7+%OOOQO7+%V7+%VOBOQPO7+%YOOQO7+%Y7+%YO@}QPO7+%YOCZQPO7+%dOOQO7+%d7+%dOBYQPO7+%dODfQPO7+%gODmQPO7+%gOOQO7+%k7+%kODtQPO7+%kOOQO7+%p7+%pOEuQPO7+%pO<pQSO7+%tO)yQPO7+%tO>QQPO7+%tO!iQPO,5:VOOQO,5:V,5:VOFvQPO'#DoO!iQPO'#DoOOQO'#Eo'#EoOGRQPO,5;rO!iQPO,5:dOOQO,5:d,5:dOG^QQO'#D}OGlQQO'#D}OOQO'#Eq'#EqOGqQQO,5;tOG|QPO,5;uO@uQPO,5:]OHXQPO,5:]OOQO-E8n-E8nOOQO'#EZ'#EZOOQO'#E['#E[OOQO'#EY'#EYOH^QPO7+%tOOQO'#EX'#EXO<sQSO'#EXOOQO7+&O7+&OOOQO7+&S7+&SOJcQPO7+&TOOQO7+&T7+&TOIbQPO7+&TOKnQPO7+&UOOQO7+&U7+&UOJmQPO7+&UOLyQPO7+&VOMQQPO7+&VOOQO7+&W7+&WOMXQPO7+&WOOQO7+&X7+&XONYQPO7+&XO! ZQQO,59gOOQO-E8k-E8kOOQO1G/Q1G/QOOQO7+$q7+$qO! xQPO7+$qOOQO7+$v7+$vO@uQPO'#CjO!!ZQPO'#E|OOQO'#E|'#E|O!#UQPO1G.kOOQO<<Gk<<GkOOQO<<Hf<<HfOOQO1G/i1G/iOOQO<<Ht<<HtO!#gQPO<<HtOOQO<<IO<<IOO!$hQPO<<IOO!%iQPO<<IROOQO<<IV<<IVOOQO<<I[<<I[O!&mQPO<<I`O<pQSO<<I`O)yQPO<<I`OOQO1G/q1G/qO@uQPO,5:ZO!'qQPO,5:ZO!'vQPO,5:ZOOQO-E8m-E8mOOQO1G1^1G1^OOQO1G0O1G0OO!(RQQO'#CxO!(dQQO'#CwOOQO,5:i,5:iO!(rQQO,5:iOOQO-E8o-E8oOOQO1G1`1G1`OOQO1G1a1G1aO!)QQPO1G/wO@uQPO1G/wO<sQSO,5:sOOQO,5:s,5:sOOQO<<Io<<IoO!)lQPO<<IoOOQO<<Ip<<IpO!*mQPO<<IpO!+nQPO<<IqOOQO<<Ir<<IrOOQO<<Is<<IsO!,rQQO'#CsO!,yQPO'#CvOOQO'#FP'#FPOOQO1G/R1G/ROOQO<<H]<<H]O!-RQPO,59UOOQO,59V,59VO! ZQQO'#ClOOQO7+$V7+$VO!-WQPO7+$VO!-cQPO7+$VOOQOAN>`AN>`OOQOAN>jAN>jO!-qQPOAN>zO<pQSOAN>zO!.uQPO1G/uO@uQPO1G/uO!/TQPO1G/uOOQO1G0T1G0TOOQO7+%c7+%cO!/YQPO7+%cO!/qQPO7+%cOOQO1G0_1G0_OOQOAN?ZAN?ZOOQOAN?[AN?[O!/xQQO'#EjO!0mQQO,59_OOQO,59_,59_O!0tQPO'#FROOQO'#Ek'#EkO!0yQPO,59bOOQO,59b,59bOOQO1G.p1G.pOOQO,59W,59WOOQO<<Gq<<GqO!1RQPO<<GqO!1^QPOG24fOOQO7+%a7+%aO!2bQPO7+%aO@uQPO7+%aOOQO<<H}<<H}O!2pQPO<<H}OOQO,5;U,5;UOOQO-E8h-E8hOOQO1G.y1G.yO! ZQQO,5;mOOQO-E8i-E8iOOQO1G.|1G.|OOQOAN=]AN=]OOQO<<H{<<H{O!3XQPO<<H{OOQOAN>iAN>iO!3gQPO1G1XOOQOAN>gAN>gOOQO7+&s7+&s",
  stateData: "!3w~O#hOSPOS~OcUOiPO!OiO!TjO!^kO!hlO!kmO!onO!toO!xpO#SqO#lhO#mhO#nhO~O#krO#vvO~OV!OOiPOm{O#kzO~Oi!VOm{O~O!TjO!Z!cO!^kO!hlO!kmO!onO!toO~O!xpO~P!vOm!iO~OVuXhuXiuXmuX#kuX#oTX#tuX#vuX~O#o!rO~OV!sOiPOm{OhsX#ksX#tsX#vsX~O#k!wO~OiPOm{O{#OO#kzO~O#t#POhrX#krX#vrX~Oh#RO#krO#vvO~OV!sOilXmlXhlX#klX#tlX#vlXclX!OlX!TlX!^lX!hlX!klX!olX!tlX!xlX#SlX#flX#llX#mlX#nlX#rlXUlXYlX{lX!zlX#olX~Om{OikXhkX#kkX#tkX#vkXckX!OkX!TkX!^kX!hkX!kkX!okX!tkX!xkX#SkX#fkX#lkX#mkX#nkX#rkXUkXYkX{kX!zkX#okX~OY#UO~OiPO~OiPOm{O~OV!OOiPOm{O~O{#OO~Oi!VO~Om#gO~Oi#jOm{O!a#nOc![a!O![a!T![a!^![a!h![a!k![a!o![a!t![a!x![a#S![a#f![a#l![a#m![a#n![a~Oi#jOm{O!a#nOc!fa!O!fa!T!fa!^!fa!h!fa!k!fa!o!fa!t!fa!x!fa#S!fa#f!fa#l!fa#m!fa#n!fa~Om{O#r#sOc!iai!ia!O!ia!T!ia!^!ia!h!ia!k!ia!o!ia!t!ia!x!ia#S!ia#f!ia#l!ia#m!ia#n!ia~Oi#uOm{Oc!ma!O!ma!T!ma!^!ma!h!ma!k!ma!o!ma!t!ma!x!ma#S!ma#f!ma#l!ma#m!ma#n!ma~Oi#yOm{Oc!ra!O!ra!T!ra!^!ra!h!ra!k!ra!o!ra!t!ra!x!ra#S!ra#f!ra#l!ra#m!ra#n!ra~OcUO{#OO!z$UO#kzO~O#k$_O~OiPOhsa#ksa#tsa#vsa~Om{O~P0[OV!sOm{O~P0[Om{Ohva#kva#tva#vva~O#o$kO~OU$mOY#UO~O#o$rO~Oh$sO~Om{Oc!Xii!Xi!O!Xi!T!Xi!^!Xi!h!Xi!k!Xi!o!Xi!t!Xi!x!Xi#S!Xi#f!Xi#l!Xi#m!Xi#n!Xi~Oi#jOm{Oc![i!O![i!T![i!^![i!h![i!k![i!o![i!t![i!x![i#S![i#f![i#l![i#m![i#n![i~O!a#nO~P2|Oi#jOm{Oc!fi!O!fi!T!fi!^!fi!h!fi!k!fi!o!fi!t!fi!x!fi#S!fi#f!fi#l!fi#m!fi#n!fi~O!a#nO~P4XO#r#sOc!iii!ii!O!ii!T!ii!^!ii!h!ii!k!ii!o!ii!t!ii!x!ii#S!ii#f!ii#l!ii#m!ii#n!ii~Om{O~P5dOi#uOc!mi!O!mi!T!mi!^!mi!h!mi!k!mi!o!mi!t!mi!x!mi#S!mi#f!mi#l!mi#m!mi#n!mi~Om{O~P6oOi#yOc!ri!O!ri!T!ri!^!ri!h!ri!k!ri!o!ri!t!ri!x!ri#S!ri#f!ri#l!ri#m!ri#n!ri~Om{O~P7wO#y%VO~P2|O#kzO#y%VO~OcUO#kzO~Oi#jOc![i!O![i!T![i!^![i!h![i!k![i!o![i!t![i!x![i#S![i#f![i#l![i#m![i#n![i~O#y%VO~P4XOi#jOc!fi!O!fi!T!fi!^!fi!h!fi!k!fi!o!fi!t!fi!x!fi#S!fi#f!fi#l!fi#m!fi#n!fi~O#{%]O~P5gO#kzO#{%]O~OcUOf%_O~O#o%dO~OcUO#kzO{!dX!z!dX#o!dX~O#{%lO$O%gO$P%gO$Q%gO$R%gO$S%gO$T%gO$U%gO$V%gO$W%hO$X%hO$Y%hO$Z%hO$[%hO$]%hO$^%hO$_%hO$`%hO$a%hO$b%hO~O{#OO!z$UO~Oi!VOc#Qi!O#Qi!T#Qi!^#Qi!h#Qi!k#Qi!o#Qi!t#Qi!x#Qi#S#Qi#f#Qi#l#Qi#m#Qi#n#Qi~Oi#jOm{O!a#nO~Om{O#r#sO~Oi#uOm{O~Oi#yOm{O~O#o%{O~OU%}O#k$_O~OiPOhsi#ksi#tsi#vsi~Om{O~P@]O]&RO#kzO~Oi#jOc![q!O![q!T![q!^![q!h![q!k![q!o![q!t![q!x![q#S![q#f![q#l![q#m![q#n![q~Om{O#y%VO~P@}Oi#jOc!fq!O!fq!T!fq!^!fq!h!fq!k!fq!o!fq!t!fq!x!fq#S!fq#f!fq#l!fq#m!fq#n!fq~Om{O#y%VO~PBYOc!iqi!iq!O!iq!T!iq!^!iq!h!iq!k!iq!o!iq!t!iq!x!iq#S!iq#f!iq#l!iq#m!iq#n!iq~O#{%]O~PCeO#r#sO~PCeOi#uOc!mq!O!mq!T!mq!^!mq!h!mq!k!mq!o!mq!t!mq!x!mq#S!mq#f!mq#l!mq#m!mq#n!mq~Oi#yOc!rq!O!rq!T!rq!^!rq!h!rq!k!rq!o!rq!t!rq!x!rq#S!rq#f!rq#l!rq#m!rq#n!rq~OcUO#kzO#o&eO~OcUOh&iO#kzO~Om&kOc!qXf!qXh!qX~Of&nO~OcUOf%_Oh&pO~OcUOh&qO#kzO~O#o&sO~O#{&tOc!vqi!vq!O!vq!T!vq!^!vq!h!vq!k!vq!o!vq!t!vq!x!vq#S!vq#f!vq#l!vq#m!vq#n!vq~Oi#jOc#Vq!O#Vq!T#Vq!^#Vq!h#Vq!k#Vq!o#Vq!t#Vq!x#Vq#S#Vq#f#Vq#l#Vq#m#Vq#n#Vq~Om{O#y%VO~PIbOi#jOc#Wq!O#Wq!T#Wq!^#Wq!h#Wq!k#Wq!o#Wq!t#Wq!x#Wq#S#Wq#f#Wq#l#Wq#m#Wq#n#Wq~Om{O#y%VO~PJmOc#Xqi#Xq!O#Xq!T#Xq!^#Xq!h#Xq!k#Xq!o#Xq!t#Xq!x#Xq#S#Xq#f#Xq#l#Xq#m#Xq#n#Xq~O#{%]O~PKxO#r#sO~PKxOi#uOc#Yq!O#Yq!T#Yq!^#Yq!h#Yq!k#Yq!o#Yq!t#Yq!x#Yq#S#Yq#f#Yq#l#Yq#m#Yq#n#Yq~Oi#yOc#Zq!O#Zq!T#Zq!^#Zq!h#Zq!k#Zq!o#Zq!t#Zq!x#Zq#S#Zq#f#Zq#l#Zq#m#Zq#n#Zq~OY'PO]&}Oa'POb'POc'POd'POe'POf'POi'OO~OiPOhsq#ksq#tsq#vsq~O#q'TOU#pXY#pXm#pX#r#pX#t#pXc#pX{#pX!z#pX#k#pX[#pXh#pX#o#pX~Om{O#r'UO#t'VOUXiYXi~Oi#jOc![y!O![y!T![y!^![y!h![y!k![y!o![y!t![y!x![y#S![y#f![y#l![y#m![y#n![y~Oi#jOc!fy!O!fy!T!fy!^!fy!h!fy!k!fy!o!fy!t!fy!x!fy#S!fy#f!fy#l!fy#m!fy#n!fy~O#{%]Oc!iyi!iy!O!iy!T!iy!^!iy!h!iy!k!iy!o!iy!t!iy!x!iy#S!iy#f!iy#l!iy#m!iy#n!iy~O#{&tOc!vyi!vy!O!vy!T!vy!^!vy!h!vy!k!vy!o!vy!t!vy!x!vy#S!vy#f!vy#l!vy#m!vy#n!vy~O#o'_O~OcUO#kzO#o'_O~OV!sOclXflXhlXmlX~Om&kOckXfkXhkX~Om&kOc!qaf!qah!qa~Om{O#r'UOc!ei{!ei!z!ei#k!eih!ei#o!ei~Oi#jOc#Vy!O#Vy!T#Vy!^#Vy!h#Vy!k#Vy!o#Vy!t#Vy!x#Vy#S#Vy#f#Vy#l#Vy#m#Vy#n#Vy~Oi#jOc#Wy!O#Wy!T#Wy!^#Wy!h#Wy!k#Wy!o#Wy!t#Wy!x#Wy#S#Wy#f#Wy#l#Wy#m#Wy#n#Wy~O#{%]Oc#Xyi#Xy!O#Xy!T#Xy!^#Xy!h#Xy!k#Xy!o#Xy!t#Xy!x#Xy#S#Xy#f#Xy#l#Xy#m#Xy#n#Xy~O['jO~P! ZOh'nO#kzO~O['oO~O#t'qOUXqYXq~Om{O#t'qOUXqYXq~O#{&tOc!v!Ri!v!R!O!v!R!T!v!R!^!v!R!h!v!R!k!v!R!o!v!R!t!v!R!x!v!R#S!v!R#f!v!R#l!v!R#m!v!R#n!v!R~Om{Oc!cih!ci#k!ci~O#o'vO~Om{Oc!eq{!eq!z!eq#k!eqh!eq#o!eq~O#r'UO~P!/YO#t'yOY#^X[#^X]#^Xa#^Xb#^Xc#^Xd#^Xe#^Xf#^Xi#^X~O['{O~P! ZO#o'|O~Oh(OO#kzO~O#t(POUXyYXy~O#{&tOc!v!Zi!v!Z!O!v!Z!T!v!Z!^!v!Z!h!v!Z!k!v!Z!o!v!Z!t!v!Z!x!v!Z#S!v!Z#f!v!Z#l!v!Z#m!v!Z#n!v!Z~Om{Oc!cqh!cq#k!cq~Om{Oc!ey{!ey!z!ey#k!eyh!ey#o!ey~Om{Oc!cyh!cy#k!cy~O#t(VOh#ui#k#ui~Odefe~",
  goto: ":k$OPPP$P$T$[PP&d&jP&nPP'Z'd'mPPPPPP'vPP'v'}*|P,T,_,c,g-k-o-s-w-o.O-o.U.[P$P.oP.s.w.{/bP/l/|.w0P0TP0P0ZP0e0wP1P2T2X2e0P2nP0P2xP3S0P3dP3n4O0P4SP4^.w4nP4uP5P5]5i5i.s5q5uP5q5y5y5y5y5y5y5}6T6Z6a6g7r7x8O8U8cPPP8i8mPPPPP8qPP9WP9eP8m9iP9qP:Z:cTTOgSQOgR#]!VSsPyQ!SQS!TSvQ!dXQ!eYQ!fZQ!g[Q!h]Q#a![Q#b!]Q#c!^Q#d!_Q#e!`Q#f!a^#}!i#g#y$Q%X%c&gQ$X!kQ$Y!lQ$Z!mQ$[!nQ$]!oQ$^!pj$g!z#i#s$k$r%V%]%d&R&e&s'_'vS%X#j%[Q%e$OQ&g%YT'k'O'mQ!RQR#Z!ST#V!O#WQ$h!zQ%W#iQ%^#s^&S$k%d&R&e&s'_'vQ&X$rQ&d%VR&j%]_&S$k%d&R&e&s'_'v_&T$k%d&R&e&s'_'vQ'X&UQ'c&rR'x'dZ'P%{&}'U'i'|Q!QQQ!YVQ!utQ!|vS#Y!R!SQ#`!ZQ#m!dQ#q!eQ#t!fQ#x!gQ#|!hQ$W!jS$d!v!xQ$f!yQ$j!}Q$o#ZQ$q#[Q$u#aS$x#b#hS${#c#oQ$}#dQ%P#eQ%R#fQ%n$XQ%q$YQ%t$ZQ%v$[Q%x$]Q%z$^Q&P$eQ&Z$vQ&]$yQ&m%_Q&w%oQ&y%rQ'W&UQ'a&nQ'b&rQ'r'XQ't'^S'w'c'dQ(Q'uQ(S'xR(U(R#Z|QVtv}!R!S!Z!d!e!f!g!h!j!v!x!y!}#Z#[#a#b#c#d#e#f#h#o$X$Y$Z$[$]$^$e$v$y%_%o%r&U&l&n&r'X'^'c'd'u'x(RQ!vtS#S{&kR$e!xT$a!s$bT$`!s$bSROgQ!PQQ!ttQ!{vU#X!Q!R!SU$c!u!v!xS$i!|!}S$n#Y#ZQ$p#[S&O$d$eQ&Q$jQ&V$oQ&W$qR'R&PTxPyTwPyTuPyStPyR!xuQ!USR!yvQ!}vR#[!US!zv!UQ$R!iU%S#g$S$TS&b%T%UR']&cTSOgTdOgT`OgSWOg^$O!i#g#y$Q%X%c&gS%Y#j%[T%`#u%bSVOgQ!ZWR!jaQ!XVS#_!Y!ZQ$V!jQ$t#`R%m$WR#^!VT^OgQ![WR!kaSXOgQ!]WR!laQ#h!dQ#o!eQ$v#bQ$y#cQ%o$YR%r$Z]#i!d!e#b#c$Y$ZQ#l!dQ#p!eU$w#b#h#mU$z#c#o#qQ%p$YQ%s$ZS&Y$v$xS&[$y${S&v%o%qS&x%r%tQ'Y&ZQ'Z&]Q'f&wR'g&yT%Z#j%[Q$T!iQ%U#gQ&f%XR'`&g_$P!i#g#y$Q%X%c&gSYOgQ!^WR!maSZOgQ!_WR!naQ#r!fS$|#d#tQ%u$[Q&^$}R&z%vS[OgQ!`WR!oaQ#w!gS%O#e#xQ%w$]Q&_%PR&{%xT%a#u%bS]OgQ!aWR!paQ#{!hS%Q#f#|Q%y$^Q&`%RR&|%zS_OgR!bWQ$S!iS%T#g$TR&c%UQ%j$RQ&a%SQ'[&bR's']W%k$R%S&b']Q&u%lR'e&t]%i$R%S%l&b&t']TcOgTaOgTbOgQgOR!qgQ#W!OR$l#WQ'i&}R'z'iQ'm'OR'}'m#Q}QVtv!R!S!Z!d!e!f!g!h!j!v!x!y!}#Z#[#a#b#c#d#e#f#h#o$X$Y$Z$[$]$^$e$v$y%o%r&U&r'X'^'c'd'u'x(RS#T}&lT&l%_&nQ$b!sR%|$bQyPR#QyQ%[#jR&h%[W$Q!i#g%X&gQ%c#yT%f$Q%cQ%b#uR&o%bTfOgTeOgQ&U$kQ&r%dQ'S&RQ'^&eQ'd&sQ'u'_R(R'vQ'Q%{S'h&}'iQ'p'UR(T'|T'l'O'm]!WV!Y!Z!j#`$W}#k!d!e#b#c#h#m#o#q$Y$Z$v$x$y${%o%q%r%t&Z&]&w&y]#v!g#e#x$]%P%x]#z!h#f#|$^%R%z",
  nodeNames: "⚠ Comment Document OperationDefinition OperationType Name ) ( VariableDefinitions VariableDefinition Variable NamedType ] [ ListType NonNullType DefaultValue IntValue FloatValue StringValue BooleanValue NullValue EnumValue ListValue } { ObjectValue Directives Directive DirectiveName Arguments Argument ArgumentAttributeName SelectionSet Selection Field Alias FieldName FragmentSpread FragmentName InlineFragment TypeCondition OnKeyword on FragmentDefinition FragmentKeyword fragment TypeSystemDefinition SchemaDefinition Description SchemaKeyword schema RootTypeDefinition RootOperationTypeDefinition TypeDefinition ScalarTypeDefinition ScalarKeyword scalar ObjectTypeDefinition TypeKeyword type ImplementsInterfaces ImplementsKeyword implements FieldsDefinition FieldDefinition ArgumentsDefinition InputValueDefinition InterfaceTypeDefinition InterfaceKeyword interface UnionTypeDefinition UnionKeyword union UnionMemberTypes EnumTypeDefinition EnumKeyword enum EnumValuesDefinition EnumValueDefinition InputObjectTypeDefinition InputKeyword input InputFieldsDefinition DirectiveDefinition DirectiveKeyword directive RepeatableKeyword repeatable DirectiveLocations DirectiveLocation ExecutableDirectiveLocation TypeSystemDirectiveLocation TypeSystemExtension SchemaExtension ExtendKeyword extend TypeExtension ScalarTypeExtension ObjectTypeExtension InterfaceTypeExtension UnionTypeExtension EnumTypeExtension InputObjectTypeExtension",
  maxTerm: 156,
  nodeProps: [
    ["openedBy", 6,"(",12,"[",24,"{"],
    ["closedBy", 7,")",13,"]",25,"}"]
  ],
  skippedNodes: [0,1],
  repeatNodeCount: 10,
  tokenData: "#8g~R!XX^$npq$nqr%crs%hst)ntu)yvw*hxy*myz*r|}*w}!O*|!O!P,e!Q![+S![!],v!_!`,{!b!c-Q!c!d-o!d!g.Y!g!h8X!h!i=b!i!k.Y!k!l!$t!l!o.Y!o!p!>b!p!q.Y!q!r!Bk!r!s.Y!s!t!Es!t!u.Y!u!v!Hb!v!w.Y!w!x#%l!x!y#(Z!y!}.Y!}#O#2Y#P#Q#2_#R#S.Y#T#Y.Y#Y#Z#2d#Z#b.Y#b#c#5O#c#h.Y#h#i#7S#i#o.Y#o#p#8W#p#q#8]#q#r#8b#y#z$n$f$g$n#BY#BZ$n$IS$I_$n$I|$JO$n$JT$JU$n$KV$KW$n&FU&FV$n~$sY#h~X^$npq$n#y#z$n$f$g$n#BY#BZ$n$IS$I_$n$I|$JO$n$JT$JU$n$KV$KW$n&FU&FV$n~%hO#q~~%kVOY&QZ]&Q^r&Qrs(as#O&Q#O#P&o#P~&Q~&TVOY&QZ]&Q^r&Qrs&js#O&Q#O#P&o#P~&Q~&oOc~~&rXrs&Q!P!Q&Q#O#P&Q#U#V&Q#Y#Z&Q#b#c&Q#f#g&Q#h#i&Q#i#j'_~'bR!Q!['k!c!i'k#T#Z'k~'nR!Q!['w!c!i'w#T#Z'w~'zR!Q![(T!c!i(T#T#Z(T~(WR!Q![&Q!c!i&Q#T#Z&Q~(fPc~rs(i~(lQrs(r#O#P)[~(uROr(irs)Os~(i~)RROr(irs&js~(i~)_Prs)b~)ePrs)h~)kPrs(i~)sQP~OY)nZ~)n~)|R!c!}*V#R#S*V#T#o*V~*[SY~!Q![*V!c!}*V#R#S*V#T#o*V~*mO#y~~*rOV~~*wOU~~*|O#t~~+PP!Q![+S~+XSa~!O!P+e!Q![+S!g!h+y#X#Y+y~+hP!Q![+k~+pRb~!Q![+k!g!h+y#X#Y+y~+|R{|,V}!O,V!Q![,]~,YP!Q![,]~,bPb~!Q![,]~,hP!O!P,k~,nP!O!P,q~,vO#v~~,{O#o~~-QO#r~~-TR!c!}-^#R#S-^#T#o-^~-cSm~!Q![-^!c!}-^#R#S-^#T#o-^V-vU#kPfQ!Q![.Y!c!t.Y!t!u.m!u!}.Y#R#S.Y#T#o.YR.aS#kPfQ!Q![.Y!c!}.Y#R#S.Y#T#o.YV.tU#kPfQ!Q![.Y!c!i.Y!i!j/W!j!}.Y#R#S.Y#T#o.YV/_U#kPfQ!Q![.Y!c!w.Y!w!x/q!x!}.Y#R#S.Y#T#o.YV/xU#kPfQ!Q![.Y!c!o.Y!o!p0[!p!}.Y#R#S.Y#T#o.YV0cU#kPfQ!Q![.Y!c!g.Y!g!h0u!h!}.Y#R#S.Y#T#o.YV0|U#kPfQ!Q![.Y!c!p.Y!p!q1`!q!}.Y#R#S.Y#T#o.YV1gU#kPfQ!Q![.Y!c!v.Y!v!w1y!w!}.Y#R#S.Y#T#o.YV2QS#kPfQ!Q![.Y!c!}.Y#R#S2^#T#o.YV2eU#kPfQ!Q![.Y!c!f.Y!f!g2w!g!}.Y#R#S.Y#T#o.YV3OU#kPfQ!Q![.Y!c!g.Y!g!h3b!h!}.Y#R#S.Y#T#o.YV3iU#kPfQ!Q![.Y!c!h.Y!h!i3{!i!}.Y#R#S.Y#T#o.YV4SU#kPfQ!Q![.Y!c!k.Y!k!l4f!l!}.Y#R#S.Y#T#o.YV4mU#kPfQ!Q![.Y!c!p.Y!p!q5P!q!}.Y#R#S.Y#T#o.YV5WU#kPfQ!Q![.Y!c!k.Y!k!l5j!l!}.Y#R#S.Y#T#o.YV5qU#kPfQ!Q![.Y!c!v.Y!v!w6T!w!}.Y#R#S.Y#T#o.YV6[U#kPfQ!Q![.Y!c!k.Y!k!l6n!l!}.Y#R#S.Y#T#o.YV6uU#kPfQ!Q![.Y!c!q.Y!q!r7X!r!}.Y#R#S.Y#T#o.YV7`U#kPfQ!Q![.Y!c!p.Y!p!q7r!q!}.Y#R#S.Y#T#o.YV7{S$[S#kPfQ!Q![.Y!c!}.Y#R#S.Y#T#o.YV8`U#kPfQ!Q![.Y!c!p.Y!p!q8r!q!}.Y#R#S.Y#T#o.YV8yU#kPfQ!Q![.Y!c!w.Y!w!x9]!x!}.Y#R#S.Y#T#o.YV9dU#kPfQ!Q![.Y!c!o.Y!o!p9v!p!}.Y#R#S.Y#T#o.YV:PS$_S#kPfQ!Q![.Y!c!}.Y#R#S:]#T#o.YV:dU#kPfQ!Q![.Y!c!x.Y!x!y:v!y!}.Y#R#S.Y#T#o.YV:}T#kPfQ!Q![.Y!c!d;^!d!}.Y#R#S.Y#T#o.YV;eU#kPfQ!Q![.Y!c!n.Y!n!o;w!o!}.Y#R#S.Y#T#o.YV<OU#kPfQ!Q![.Y!c!w.Y!w!x<b!x!}.Y#R#S.Y#T#o.YV<iU#kPfQ!Q![.Y!c!g.Y!g!h<{!h!}.Y#R#S.Y#T#o.YV=US$`S#kPfQ!Q![.Y!c!}.Y#R#S.Y#T#o.YV=iW#kPfQ!Q![.Y!c!k.Y!k!l>R!l!t.Y!t!uFQ!u!}.Y#R#S.Y#T#o.YV>YU#kPfQ!Q![.Y!c!g.Y!g!h>l!h!}.Y#R#S.Y#T#o.YV>sU#kPfQ!Q![.Y!c!n.Y!n!o?V!o!}.Y#R#S.Y#T#o.YV?^U#kPfQ!Q![.Y!c!f.Y!f!g?p!g!}.Y#R#S.Y#T#o.YV?yS$RS#kPfQ!Q![.Y!c!}.Y#R#S@V#T#o.YV@^U#kPfQ!Q![.Y!c!f.Y!f!g@p!g!}.Y#R#S.Y#T#o.YV@wU#kPfQ!Q![.Y!c!g.Y!g!hAZ!h!}.Y#R#S.Y#T#o.YVAbU#kPfQ!Q![.Y!c!h.Y!h!iAt!i!}.Y#R#S.Y#T#o.YVA{U#kPfQ!Q![.Y!c!k.Y!k!lB_!l!}.Y#R#S.Y#T#o.YVBfU#kPfQ!Q![.Y!c!p.Y!p!qBx!q!}.Y#R#S.Y#T#o.YVCPU#kPfQ!Q![.Y!c!k.Y!k!lCc!l!}.Y#R#S.Y#T#o.YVCjU#kPfQ!Q![.Y!c!v.Y!v!wC|!w!}.Y#R#S.Y#T#o.YVDTU#kPfQ!Q![.Y!c!k.Y!k!lDg!l!}.Y#R#S.Y#T#o.YVDnU#kPfQ!Q![.Y!c!q.Y!q!rEQ!r!}.Y#R#S.Y#T#o.YVEXU#kPfQ!Q![.Y!c!p.Y!p!qEk!q!}.Y#R#S.Y#T#o.YVEtS$ZS#kPfQ!Q![.Y!c!}.Y#R#S.Y#T#o.YVFXT#kPfQ!Q![.Y!c!dFh!d!}.Y#R#S.Y#T#o.YVFoU#kPfQ!Q![.Y!c!i.Y!i!jGR!j!}.Y#R#S.Y#T#o.YVGYU#kPfQ!Q![.Y!c!o.Y!o!pGl!p!}.Y#R#S.Y#T#o.YVGsU#kPfQ!Q![.Y!c!g.Y!g!hHV!h!}.Y#R#S.Y#T#o.YVH^U#kPfQ!Q![.Y!c!p.Y!p!qHp!q!}.Y#R#S.Y#T#o.YVHwU#kPfQ!Q![.Y!c!v.Y!v!wIZ!w!}.Y#R#S.Y#T#o.YVIbS#kPfQ!Q![.Y!c!}.Y#R#SIn#T#o.YVIuW#kPfQ!Q![.Y!c!f.Y!f!gJ_!g!u.Y!u!v! o!v!}.Y#R#S.Y#T#o.YVJfU#kPfQ!Q![.Y!c!g.Y!g!hJx!h!}.Y#R#S.Y#T#o.YVKPU#kPfQ!Q![.Y!c!h.Y!h!iKc!i!}.Y#R#S.Y#T#o.YVKjU#kPfQ!Q![.Y!c!k.Y!k!lK|!l!}.Y#R#S.Y#T#o.YVLTU#kPfQ!Q![.Y!c!p.Y!p!qLg!q!}.Y#R#S.Y#T#o.YVLnU#kPfQ!Q![.Y!c!k.Y!k!lMQ!l!}.Y#R#S.Y#T#o.YVMXU#kPfQ!Q![.Y!c!v.Y!v!wMk!w!}.Y#R#S.Y#T#o.YVMrU#kPfQ!Q![.Y!c!k.Y!k!lNU!l!}.Y#R#S.Y#T#o.YVN]U#kPfQ!Q![.Y!c!q.Y!q!rNo!r!}.Y#R#S.Y#T#o.YVNvU#kPfQ!Q![.Y!c!p.Y!p!q! Y!q!}.Y#R#S.Y#T#o.YV! cS$SS#kPfQ!Q![.Y!c!}.Y#R#S.Y#T#o.YV! vU#kPfQ!Q![.Y!c!r.Y!r!s!!Y!s!}.Y#R#S.Y#T#o.YV!!aU#kPfQ!Q![.Y!c!t.Y!t!u!!s!u!}.Y#R#S.Y#T#o.YV!!zU#kPfQ!Q![.Y!c!g.Y!g!h!#^!h!}.Y#R#S.Y#T#o.YV!#eT#kPfQ!Q![.Y!c!d!#t!d!}.Y#R#S.Y#T#o.YV!#{U#kPfQ!Q![.Y!c!f.Y!f!g!$_!g!}.Y#R#S.Y#T#o.YV!$hS$TS#kPfQ!Q![.Y!c!}.Y#R#S.Y#T#o.YV!${U#kPfQ!Q![.Y!c!p.Y!p!q!%_!q!}.Y#R#S.Y#T#o.YV!%fY#kPfQ!Q![.Y!c!n.Y!n!o!&U!o!r.Y!r!s!,z!s!v.Y!v!w!:r!w!}.Y#R#S.Y#T#o.YV!&]U#kPfQ!Q![.Y!c!k.Y!k!l!&o!l!}.Y#R#S.Y#T#o.YV!&vU#kPfQ!Q![.Y!c!p.Y!p!q!'Y!q!}.Y#R#S.Y#T#o.YV!'aU#kPfQ!Q![.Y!c!g.Y!g!h!'s!h!}.Y#R#S.Y#T#o.YV!'zS#kPfQ!Q![.Y!c!}.Y#R#S!(W#T#o.YV!(_U#kPfQ!Q![.Y!c!h.Y!h!i!(q!i!}.Y#R#S.Y#T#o.YV!(xU#kPfQ!Q![.Y!c!t.Y!t!u!)[!u!}.Y#R#S.Y#T#o.YV!)cT#kPfQ!Q![.Y!c!d!)r!d!}.Y#R#S.Y#T#o.YV!)yU#kPfQ!Q![.Y!c!i.Y!i!j!*]!j!}.Y#R#S.Y#T#o.YV!*dU#kPfQ!Q![.Y!c!o.Y!o!p!*v!p!}.Y#R#S.Y#T#o.YV!*}U#kPfQ!Q![.Y!c!g.Y!g!h!+a!h!}.Y#R#S.Y#T#o.YV!+hU#kPfQ!Q![.Y!c!p.Y!p!q!+z!q!}.Y#R#S.Y#T#o.YV!,RU#kPfQ!Q![.Y!c!v.Y!v!w!,e!w!}.Y#R#S.Y#T#o.YV!,nS$US#kPfQ!Q![.Y!c!}.Y#R#S.Y#T#o.YV!-RU#kPfQ!Q![.Y!c!w.Y!w!x!-e!x!}.Y#R#S.Y#T#o.YV!-lU#kPfQ!Q![.Y!c!v.Y!v!w!.O!w!}.Y#R#S.Y#T#o.YV!.VS#kPfQ!Q![.Y!c!}.Y#R#S!.c#T#o.YV!.jW#kPfQ!Q![.Y!c!h.Y!h!i!/S!i!q.Y!q!r!7j!r!}.Y#R#S.Y#T#o.YV!/ZU#kPfQ!Q![.Y!c!k.Y!k!l!/m!l!}.Y#R#S.Y#T#o.YV!/tU#kPfQ!Q![.Y!c!g.Y!g!h!0W!h!}.Y#R#S.Y#T#o.YV!0_U#kPfQ!Q![.Y!c!n.Y!n!o!0q!o!}.Y#R#S.Y#T#o.YV!0xU#kPfQ!Q![.Y!c!f.Y!f!g!1[!g!}.Y#R#S.Y#T#o.YV!1cS#kPfQ!Q![.Y!c!}.Y#R#S!1o#T#o.YV!1vU#kPfQ!Q![.Y!c!f.Y!f!g!2Y!g!}.Y#R#S.Y#T#o.YV!2aU#kPfQ!Q![.Y!c!g.Y!g!h!2s!h!}.Y#R#S.Y#T#o.YV!2zU#kPfQ!Q![.Y!c!h.Y!h!i!3^!i!}.Y#R#S.Y#T#o.YV!3eU#kPfQ!Q![.Y!c!k.Y!k!l!3w!l!}.Y#R#S.Y#T#o.YV!4OU#kPfQ!Q![.Y!c!p.Y!p!q!4b!q!}.Y#R#S.Y#T#o.YV!4iU#kPfQ!Q![.Y!c!k.Y!k!l!4{!l!}.Y#R#S.Y#T#o.YV!5SU#kPfQ!Q![.Y!c!v.Y!v!w!5f!w!}.Y#R#S.Y#T#o.YV!5mU#kPfQ!Q![.Y!c!k.Y!k!l!6P!l!}.Y#R#S.Y#T#o.YV!6WU#kPfQ!Q![.Y!c!q.Y!q!r!6j!r!}.Y#R#S.Y#T#o.YV!6qU#kPfQ!Q![.Y!c!p.Y!p!q!7T!q!}.Y#R#S.Y#T#o.YV!7^S$bS#kPfQ!Q![.Y!c!}.Y#R#S.Y#T#o.YV!7qU#kPfQ!Q![.Y!c!d.Y!d!e!8T!e!}.Y#R#S.Y#T#o.YV!8[U#kPfQ!Q![.Y!c!l.Y!l!m!8n!m!}.Y#R#S.Y#T#o.YV!8uU#kPfQ!Q![.Y!c!g.Y!g!h!9X!h!}.Y#R#S.Y#T#o.YV!9`U#kPfQ!Q![.Y!c!e.Y!e!f!9r!f!}.Y#R#S.Y#T#o.YV!9yU#kPfQ!Q![.Y!c!v.Y!v!w!:]!w!}.Y#R#S.Y#T#o.YV!:fS$aS#kPfQ!Q![.Y!c!}.Y#R#S.Y#T#o.YV!:yU#kPfQ!Q![.Y!c!g.Y!g!h!;]!h!}.Y#R#S.Y#T#o.YV!;dU#kPfQ!Q![.Y!c!t.Y!t!u!;v!u!}.Y#R#S.Y#T#o.YV!;}U#kPfQ!Q![.Y!c!h.Y!h!i!<a!i!}.Y#R#S.Y#T#o.YV!<hT#kPfQ!Q![.Y!c!d!<w!d!}.Y#R#S.Y#T#o.YV!=OU#kPfQ!Q![.Y!c!e.Y!e!f!=b!f!}.Y#R#S.Y#T#o.YV!=iU#kPfQ!Q![.Y!c!g.Y!g!h!={!h!}.Y#R#S.Y#T#o.YV!>US$]S#kPfQ!Q![.Y!c!}.Y#R#S.Y#T#o.YV!>iU#kPfQ!Q![.Y!c!w.Y!w!x!>{!x!}.Y#R#S.Y#T#o.YV!?SU#kPfQ!Q![.Y!c!v.Y!v!w!?f!w!}.Y#R#S.Y#T#o.YV!?mT#kPfQ!Q![.Y!c!d!?|!d!}.Y#R#S.Y#T#o.YV!@TU#kPfQ!Q![.Y!c!v.Y!v!w!@g!w!}.Y#R#S.Y#T#o.YV!@nU#kPfQ!Q![.Y!c!k.Y!k!l!AQ!l!}.Y#R#S.Y#T#o.YV!AXU#kPfQ!Q![.Y!c!q.Y!q!r!Ak!r!}.Y#R#S.Y#T#o.YV!ArU#kPfQ!Q![.Y!c!p.Y!p!q!BU!q!}.Y#R#S.Y#T#o.YV!B_S$PS#kPfQ!Q![.Y!c!}.Y#R#S.Y#T#o.YV!BrU#kPfQ!Q![.Y!c!d.Y!d!e!CU!e!}.Y#R#S.Y#T#o.YV!C]U#kPfQ!Q![.Y!c!l.Y!l!m!Co!m!}.Y#R#S.Y#T#o.YV!CvU#kPfQ!Q![.Y!c!g.Y!g!h!DY!h!}.Y#R#S.Y#T#o.YV!DaU#kPfQ!Q![.Y!c!e.Y!e!f!Ds!f!}.Y#R#S.Y#T#o.YV!DzU#kPfQ!Q![.Y!c!v.Y!v!w!E^!w!}.Y#R#S.Y#T#o.YV!EgS$YS#kPfQ!Q![.Y!c!}.Y#R#S.Y#T#o.YV!EzU#kPfQ!Q![.Y!c!w.Y!w!x!F^!x!}.Y#R#S.Y#T#o.YV!FeU#kPfQ!Q![.Y!c!g.Y!g!h!Fw!h!}.Y#R#S.Y#T#o.YV!GOU#kPfQ!Q![.Y!c!t.Y!t!u!Gb!u!}.Y#R#S.Y#T#o.YV!GiU#kPfQ!Q![.Y!c!{.Y!{!|!G{!|!}.Y#R#S.Y#T#o.YV!HUS$OS#kPfQ!Q![.Y!c!}.Y#R#S.Y#T#o.YV!HiW#kPfQ!Q![.Y!c!e.Y!e!f!IR!f!w.Y!w!x!Mq!x!}.Y#R#S.Y#T#o.YV!IYV#kPfQ!Q![.Y!c!d!Io!d!j.Y!j!k!Kp!k!}.Y#R#S.Y#T#o.YV!IvU#kPfQ!Q![.Y!c!n.Y!n!o!JY!o!}.Y#R#S.Y#T#o.YV!JaT#kPfQ!Q![.Y!c!d!Jp!d!}.Y#R#S.Y#T#o.YV!JwU#kPfQ!Q![.Y!c!t.Y!t!u!KZ!u!}.Y#R#S.Y#T#o.YV!KdS$XS#kPfQ!Q![.Y!c!}.Y#R#S.Y#T#o.YV!KwU#kPfQ!Q![.Y!c!g.Y!g!h!LZ!h!}.Y#R#S.Y#T#o.YV!LbU#kPfQ!Q![.Y!c!o.Y!o!p!Lt!p!}.Y#R#S.Y#T#o.YV!L{T#kPfQ!Q![.Y!c!d!M[!d!}.Y#R#S.Y#T#o.YV!MeS$WS#kPfQ!Q![.Y!c!}.Y#R#S.Y#T#o.YV!MxU#kPfQ!Q![.Y!c!d.Y!d!e!N[!e!}.Y#R#S.Y#T#o.YV!NcU#kPfQ!Q![.Y!c!u.Y!u!v!Nu!v!}.Y#R#S.Y#T#o.YV!N|U#kPfQ!Q![.Y!c!e.Y!e!f# `!f!}.Y#R#S.Y#T#o.YV# gU#kPfQ!Q![.Y!c!t.Y!t!u# y!u!}.Y#R#S.Y#T#o.YV#!QU#kPfQ!Q![.Y!c!k.Y!k!l#!d!l!}.Y#R#S.Y#T#o.YV#!kU#kPfQ!Q![.Y!c!r.Y!r!s#!}!s!}.Y#R#S.Y#T#o.YV##UU#kPfQ!Q![.Y!c!v.Y!v!w##h!w!}.Y#R#S.Y#T#o.YV##oU#kPfQ!Q![.Y!c!k.Y!k!l#$R!l!}.Y#R#S.Y#T#o.YV#$YU#kPfQ!Q![.Y!c!q.Y!q!r#$l!r!}.Y#R#S.Y#T#o.YV#$sU#kPfQ!Q![.Y!c!p.Y!p!q#%V!q!}.Y#R#S.Y#T#o.YV#%`S$QS#kPfQ!Q![.Y!c!}.Y#R#S.Y#T#o.YV#%sU#kPfQ!Q![.Y!c!p.Y!p!q#&V!q!}.Y#R#S.Y#T#o.YV#&^U#kPfQ!Q![.Y!c!k.Y!k!l#&p!l!}.Y#R#S.Y#T#o.YV#&wU#kPfQ!Q![.Y!c!q.Y!q!r#'Z!r!}.Y#R#S.Y#T#o.YV#'bU#kPfQ!Q![.Y!c!p.Y!p!q#'t!q!}.Y#R#S.Y#T#o.YV#'}S$^S#kPfQ!Q![.Y!c!}.Y#R#S.Y#T#o.YV#(bT#kPfQ!Q![.Y!c!d#(q!d!}.Y#R#S.Y#T#o.YV#(xU#kPfQ!Q![.Y!c!t.Y!t!u#)[!u!}.Y#R#S.Y#T#o.YV#)cU#kPfQ!Q![.Y!c!k.Y!k!l#)u!l!}.Y#R#S.Y#T#o.YV#)|T#kPfQ!Q![.Y!c!d#*]!d!}.Y#R#S.Y#T#o.YV#*dU#kPfQ!Q![.Y!c!d.Y!d!e#*v!e!}.Y#R#S.Y#T#o.YV#*}U#kPfQ!Q![.Y!c!n.Y!n!o#+a!o!}.Y#R#S.Y#T#o.YV#+hU#kPfQ!Q![.Y!c!g.Y!g!h#+z!h!}.Y#R#S.Y#T#o.YV#,RS#kPfQ!Q![.Y!c!}.Y#R#S#,_#T#o.YV#,fU#kPfQ!Q![.Y!c!f.Y!f!g#,x!g!}.Y#R#S.Y#T#o.YV#-PU#kPfQ!Q![.Y!c!g.Y!g!h#-c!h!}.Y#R#S.Y#T#o.YV#-jU#kPfQ!Q![.Y!c!h.Y!h!i#-|!i!}.Y#R#S.Y#T#o.YV#.TU#kPfQ!Q![.Y!c!k.Y!k!l#.g!l!}.Y#R#S.Y#T#o.YV#.nU#kPfQ!Q![.Y!c!p.Y!p!q#/Q!q!}.Y#R#S.Y#T#o.YV#/XU#kPfQ!Q![.Y!c!k.Y!k!l#/k!l!}.Y#R#S.Y#T#o.YV#/rU#kPfQ!Q![.Y!c!v.Y!v!w#0U!w!}.Y#R#S.Y#T#o.YV#0]U#kPfQ!Q![.Y!c!k.Y!k!l#0o!l!}.Y#R#S.Y#T#o.YV#0vU#kPfQ!Q![.Y!c!q.Y!q!r#1Y!r!}.Y#R#S.Y#T#o.YV#1aU#kPfQ!Q![.Y!c!p.Y!p!q#1s!q!}.Y#R#S.Y#T#o.YV#1|S$VS#kPfQ!Q![.Y!c!}.Y#R#S.Y#T#o.Y~#2_O]~~#2dO[~R#2kT#kPfQ!Q![.Y!c!}.Y#R#S.Y#T#U#2z#U#o.YR#3RU#kPfQ!Q![.Y!c!}.Y#R#S.Y#T#`.Y#`#a#3e#a#o.YR#3lU#kPfQ!Q![.Y!c!}.Y#R#S.Y#T#g.Y#g#h#4O#h#o.YR#4VU#kPfQ!Q![.Y!c!}.Y#R#S.Y#T#X.Y#X#Y#4i#Y#o.YR#4rS#kPdQfQ!Q![.Y!c!}.Y#R#S.Y#T#o.YR#5VU#kPfQ!Q![.Y!c!}.Y#R#S.Y#T#i.Y#i#j#5i#j#o.YR#5pU#kPfQ!Q![.Y!c!}.Y#R#S.Y#T#`.Y#`#a#6S#a#o.YR#6ZU#kPfQ!Q![.Y!c!}.Y#R#S.Y#T#`.Y#`#a#6m#a#o.YR#6vS#kPeQfQ!Q![.Y!c!}.Y#R#S.Y#T#o.YR#7ZU#kPfQ!Q![.Y!c!}.Y#R#S.Y#T#f.Y#f#g#7m#g#o.YR#7tU#kPfQ!Q![.Y!c!}.Y#R#S.Y#T#i.Y#i#j#4O#j#o.Y~#8]Oi~~#8bO#{~~#8gOh~",
  tokenizers: [0, 1, 2],
  topRules: {"Document":[0,2]},
  specialized: [{term: 119, get: value => spec_name[value] || -1}],
  tokenPrec: 2978
});

const nodesWithBraces = 'RootTypeDefinition InputFieldsDefinition EnumValuesDefinition FieldsDefinition SelectionSet { }';
const keywords = 'scalar type interface union enum input implements fragment extend schema directive on repeatable';
const punctuations = '( ) { } : [ ]';
const graphqlLanguage = /*@__PURE__*/LRLanguage.define({
    parser: /*@__PURE__*/parser.configure({
        props: [
            /*@__PURE__*/styleTags({
                Variable: tags.variableName,
                BooleanValue: tags.bool,
                StringValue: tags.string,
                Comment: tags.lineComment,
                IntValue: tags.integer,
                FloatValue: tags.float,
                EnumValue: /*@__PURE__*/tags.special(tags.name),
                NullValue: tags.null,
                DirectiveName: tags.modifier,
                [keywords]: tags.keyword,
                OperationType: tags.definitionKeyword,
                FieldName: tags.propertyName,
                Field: tags.propertyName,
                ArgumentAttributeName: tags.attributeName,
                Name: tags.atom,
                '( )': tags.paren,
                '{ }': tags.brace,
                ',': tags.separator,
                [punctuations]: tags.punctuation,
            }),
            // https://codemirror.net/docs/ref/#language.indentNodeProp
            /*@__PURE__*/indentNodeProp.add({
                [nodesWithBraces]: /*@__PURE__*/delimitedIndent({ closing: '}', align: true }),
            }),
            /*@__PURE__*/foldNodeProp.add({
                [nodesWithBraces]: foldInside,
            }),
        ],
    }),
    languageData: {
        commentTokens: { line: '#' },
        indentOnInput: /^\s*(\{|\})$/,
    },
});
function graphqlLanguageSupport() {
    return new LanguageSupport(graphqlLanguage);
}

const AUTOCOMPLETE_CHARS = /^[a-zA-Z0-9_@(]$/;
const completion = /*@__PURE__*/graphqlLanguage.data.of({
    autocomplete(ctx) {
        const schema = getSchema(ctx.state);
        const opts = getOpts(ctx.state);
        if (!schema) {
            return null;
        }
        const word = ctx.matchBefore(/\w*/);
        if (!word) {
            return null;
        }
        const lastWordChar = word.text.split('').pop();
        if (!AUTOCOMPLETE_CHARS.test(lastWordChar) && !ctx.explicit) {
            return null;
        }
        const val = ctx.state.doc.toString();
        const pos = offsetToPos(ctx.state.doc, ctx.pos);
        const results = getAutocompleteSuggestions(schema, val, pos);
        if (results.length === 0) {
            return null;
        }
        return {
            from: word.from,
            options: results.map(item => {
                return {
                    label: item.label,
                    detail: item.detail || '',
                    info(completionData) {
                        if (opts === null || opts === void 0 ? void 0 : opts.onCompletionInfoRender) {
                            return opts.onCompletionInfoRender(item, ctx, completionData);
                        }
                        if (item.documentation ||
                            (item.isDeprecated && item.deprecationReason)) {
                            const el = document.createElement('div');
                            el.textContent =
                                item.documentation || item.deprecationReason || '';
                            return el;
                        }
                    },
                };
            }),
        };
    },
});

const jump = /*@__PURE__*/EditorView.domEventHandlers({
    click(evt, view) {
        var _a, _b, _c;
        const schema = getSchema(view.state);
        if (!schema) {
            return;
        }
        // TODO: Set class on cm-editor when mod key is pressed, to style cursor and tokens
        const currentPosition = view.state.selection.main.head;
        const pos = offsetToPos(view.state.doc, currentPosition);
        const token = getTokenAtPosition(view.state.doc.toString(), pos);
        const tInfo = getTypeInfo(schema, token.state);
        const opts = getOpts(view.state);
        if ((opts === null || opts === void 0 ? void 0 : opts.onShowInDocs) && isMetaKeyPressed(evt)) {
            opts.onShowInDocs((_a = tInfo.fieldDef) === null || _a === void 0 ? void 0 : _a.name, (_b = tInfo.type) === null || _b === void 0 ? void 0 : _b.toString(), (_c = tInfo.parentType) === null || _c === void 0 ? void 0 : _c.toString());
        }
    },
});

const SEVERITY = ['error', 'warning', 'info'];
const lint = /*@__PURE__*/linter(view => {
    const schema = getSchema(view.state);
    if (!schema) {
        return [];
    }
    const results = getDiagnostics(view.state.doc.toString(), schema);
    return results
        .map((item) => {
        if (!item.severity || !item.source) {
            return null;
        }
        const calculatedFrom = posToOffset(view.state.doc, new Position(item.range.start.line, item.range.start.character));
        const from = Math.max(0, Math.min(calculatedFrom, view.state.doc.length));
        const calculatedRo = posToOffset(view.state.doc, new Position(item.range.end.line, item.range.end.character - 1));
        const to = Math.min(Math.max(from + 1, calculatedRo), view.state.doc.length);
        return {
            from,
            to: from === to ? to + 1 : to,
            severity: SEVERITY[item.severity - 1],
            // source: item.source, // TODO:
            message: item.message,
            actions: [], // TODO:
        };
    })
        .filter((_) => Boolean(_));
});

function graphql(schema, opts) {
    return [
        graphqlLanguageSupport(),
        completion,
        lint,
        jump,
        stateExtensions(schema, opts),
    ];
}

export { Position, completion, fillAllFieldsCommands, getOpts, getSchema, graphql, graphqlLanguage, graphqlLanguageSupport, isMetaKeyPressed, jump, lint, offsetToPos, posToOffset, showInDocsCommand, stateExtensions, updateOpts, updateSchema };
